@@ -30,8 +30,9 @@
 
 /* Duplicate N bytes of data buffer, with out-of-memory checking. */
 extern void *
-xmemdup (void *dest, const void *src, size_t n)
+xmemdup (const void *src, size_t n)
 {
+  void *dest;
   dest = xmalloc (n);
   memcpy (dest, src, n);
   return dest;
