@@ -32,6 +32,7 @@ enum
   KDC_RETRIES_OPTION,
   TICKET_LIFE_OPTION,
   RENEW_LIFE_OPTION,
+  AUTHORIZATION_TYPES_OPTION,
   VERBOSE_CRYPTO_NOICE_OPTION,
   VERBOSE_CRYPTO_OPTION,
   VERBOSE_ASN1_OPTION,
@@ -51,6 +52,7 @@ static char *const _shishi_opts[] = {
   /* [KDC_RETRIES_OPTION] =          */ "kdc-retries",
   /* [TICKET_LIFE_OPTION] =          */ "ticket-life",
   /* [RENEW_LIFE_OPTION] =           */ "renew-life",
+  /* [AUTHORIZATION_TYPES_OPTION] =  */ "authorization-types",
   /* [VERBOSE_CRYPTO_NOICE_OPTION] = */ "verbose-crypto-noice",
   /* [VERBOSE_CRYPTO_OPTION] =       */ "verbose-crypto",
   /* [VERBOSE_ASN1_OPTION] =         */ "verbose-asn1",
@@ -219,6 +221,12 @@ shishi_cfg (Shishi * handle, char *option)
 	    return res;
 	  break;
 
+	case AUTHORIZATION_TYPES_OPTION:
+	  res = shishi_cfg_authorizationtype_set (handle, value);
+	  if (res != SHISHI_OK)
+	    return res;
+	  break;
+
 	case STRINGPROCESS_OPTION:
 	  handle->stringprocess = xstrdup (value);
 	  break;
@@ -325,7 +333,7 @@ shishi_cfg (Shishi * handle, char *option)
 int
 shishi_cfg_from_file (Shishi * handle, const char *cfg)
 {
-  char line[BUFSIZ];
+  struct linebuffer lb;
   FILE *fh;
 
   if (cfg == NULL)
@@ -338,31 +346,33 @@ shishi_cfg_from_file (Shishi * handle, const char *cfg)
       return SHISHI_FOPEN_ERROR;
     }
 
-  while (!feof (fh) && !ferror (fh))
+  initbuffer (&lb);
+
+  while (readlinebuffer (&lb, fh))
     {
-      if (!fgets (line, sizeof (line), fh))
+      char *p = lb.buffer;
+      char *q;
+
+      p[lb.length - 1] = '\0';
+
+      while (*p && strchr (" \t\r\n", *p))
+	p++;
+
+      if (*p == '\0' || *p == '#')
 	continue;
 
-      line[strlen (line) - 1] = '\0';
+      q = strchr (p, ' ');
+      if (q && (strchr (p, '=') == NULL || q < strchr (p, '=')))
+	*q = '=';
 
-      while (line[0] && strchr (" \t\r\n", line[0]))
-	memmove (line, line + 1, strlen (line));
-
-      if (line[0] == '#' || line[0] == '\0')
-	continue;
-
-      if (strchr (line, ' ') && (strchr (line, '=') == NULL ||
-				 strchr (line, ' ') < strchr (line, '=')))
-	{
-	  char *p = strchr (line, ' ');
-	  while (*(p + 1) == ' ' || *(p + 1) == '=')
-	    memmove (p, p + 1, strlen (p + 1) + 1);
-	  *p = '=';
-	}
-
-      shishi_cfg (handle, line);
+      shishi_cfg (handle, p);
     }
 
+  if (ferror (fh))
+    shishi_error_printf (handle, "Error reading configuration file");
+
+  freebuffer (&lb);
+
   if (fclose (fh) != 0)
     return SHISHI_FCLOSE_ERROR;
 
@@ -535,3 +545,48 @@ shishi_cfg_clientkdcetype_set (Shishi * handle, char *value)
 
   return SHISHI_OK;
 }
+
+/**
+ * shishi_cfg_authorizationtype_set:
+ * @handle: Shishi library handle create by shishi_init().
+ * @value: string with authorization types.
+ *
+ * Set the "authorization-types" configuration option from given string.
+ * The string contains authorization types (integer or names) separated
+ * by comma or whitespace, e.g. "basic k5login".
+ *
+ * Return value: Return SHISHI_OK iff successful.
+ **/
+int
+shishi_cfg_authorizationtype_set (Shishi * handle, char *value)
+{
+  char *ptrptr;
+  char *val;
+  int i;
+  int tot = 0;
+
+  if (value == NULL || *value == '\0')
+    return SHISHI_OK;
+
+  for (i = 0; (val = strtok_r (i == 0 ? value : NULL, ", \t", &ptrptr)); i++)
+    {
+      int atype = shishi_authorization_parse (val);
+
+      if (atype == -1)
+	shishi_warn (handle, "Ignoring unknown authorization type: `%s'",
+		     val);
+      else
+	{
+	  int *new;
+
+	  tot++;
+	  new = xrealloc (handle->authorizationtypes,
+			  tot * sizeof (*handle->authorizationtypes));
+	  handle->authorizationtypes = new;
+	  handle->authorizationtypes[tot - 1] = atype;
+	  handle->nauthorizationtypes = tot;
+	}
+    }
+
+  return SHISHI_OK;
+}
