@@ -257,7 +257,7 @@ _shishi_simplified_dencrypt (Shishi * handle,
       memset (pt + inlen, 0, padzerolen);
     }
   else
-    pt = (char*) in;
+    pt = (char *) in;
 
   switch (shishi_key_type (key))
     {
@@ -660,20 +660,32 @@ shishi_cipher_defaultcksumtype (int32_t type)
   return -1;
 }
 
-static struct {
+static struct
+{
   char *name;
   int type;
-} cipher_aliases[] = {
-  { "des-crc", SHISHI_DES_CBC_CRC },
-  { "des-md4", SHISHI_DES_CBC_MD4 },
-  { "des-md5", SHISHI_DES_CBC_MD5 },
-  { "des", SHISHI_DES_CBC_MD5 },
-  { "des3", SHISHI_DES3_CBC_HMAC_SHA1_KD },
-  { "3des", SHISHI_DES3_CBC_HMAC_SHA1_KD },
-  { "aes128", SHISHI_AES128_CTS_HMAC_SHA1_96 },
-  { "aes256", SHISHI_AES256_CTS_HMAC_SHA1_96 },
-  { "aes", SHISHI_AES256_CTS_HMAC_SHA1_96 },
-  { "arcfour", SHISHI_ARCFOUR_HMAC }
+} cipher_aliases[] =
+{
+  {
+  "des-crc", SHISHI_DES_CBC_CRC},
+  {
+  "des-md4", SHISHI_DES_CBC_MD4},
+  {
+  "des-md5", SHISHI_DES_CBC_MD5},
+  {
+  "des", SHISHI_DES_CBC_MD5},
+  {
+  "des3", SHISHI_DES3_CBC_HMAC_SHA1_KD},
+  {
+  "3des", SHISHI_DES3_CBC_HMAC_SHA1_KD},
+  {
+  "aes128", SHISHI_AES128_CTS_HMAC_SHA1_96},
+  {
+  "aes256", SHISHI_AES256_CTS_HMAC_SHA1_96},
+  {
+  "aes", SHISHI_AES256_CTS_HMAC_SHA1_96},
+  {
+  "arcfour", SHISHI_ARCFOUR_HMAC}
 };
 
 /**
