@@ -569,7 +569,7 @@ shishi_kdcreq_set_etype (Shishi * handle,
  * Return value: Returns SHISHI_OK iff successful.
  **/
 int
-shishi_kdcreq_options (Shishi * handle, Shishi_asn1 kdcreq, uint32_t *flags)
+shishi_kdcreq_options (Shishi * handle, Shishi_asn1 kdcreq, uint32_t * flags)
 {
   return shishi_asn1_read_bitstring (handle, kdcreq,
 				     "req-body.kdc-options", flags);
@@ -614,8 +614,7 @@ shishi_kdcreq_renewable_p (Shishi * handle, Shishi_asn1 kdcreq)
  **/
 int
 shishi_kdcreq_options_set (Shishi * handle,
-			   Shishi_asn1 kdcreq,
-			   uint32_t options)
+			   Shishi_asn1 kdcreq, uint32_t options)
 {
   int res;
 
@@ -639,8 +638,7 @@ shishi_kdcreq_options_set (Shishi * handle,
  **/
 int
 shishi_kdcreq_options_add (Shishi * handle,
-			   Shishi_asn1 kdcreq,
-			   uint32_t option)
+			   Shishi_asn1 kdcreq, uint32_t option)
 {
   int options;
   int res;
