@@ -27,7 +27,7 @@
 #include <time.h>		/* time_t */
 #include <shishi-int.h>		/* uint32_t */
 
-#define SHISHI_VERSION "0.0.7"
+#define SHISHI_VERSION "0.0.8"
 
 /* Error codes */
 typedef enum
@@ -307,6 +307,13 @@ typedef enum
 }
 Shishi_outputtype;
 
+typedef enum
+{
+  SHISHI_AUTHORIZATION_BASIC = 0,
+  SHISHI_AUTHORIZATION_K5LOGIN
+}
+Shishi_authorization;
+
 typedef enum
 {
   /* 1. AS-REQ PA-ENC-TIMESTAMP padata timestamp, encrypted with the
@@ -365,16 +372,27 @@ typedef enum
      (raeburn/MIT) */
   SHISHI_KEYUSAGE_GSS_R1 = 22,
   SHISHI_KEYUSAGE_GSS_R2 = 23,
-  SHISHI_KEYUSAGE_GSS_R3 = 24
-    /* 16-18,20-21,25-511. Reserved for future use in Kerberos and related
-       protocols.
-       512-1023.      Reserved for uses internal to a Kerberos
-       implementation.
-       1024.         Encryption for application use in protocols that
-       do not specify key usage values
-       1025.         Checksums for application use in protocols that
-       do not specify key usage values
-       1026-2047.      Reserved for application use. */
+  SHISHI_KEYUSAGE_GSS_R3 = 24,
+  /* draft-ietf-krb-wg-gssapi-cfx */
+  SHISHI_KEYUSAGE_ACCEPTOR_SEAL = 22,
+  SHISHI_KEYUSAGE_ACCEPTOR_SIGN = 23,
+  SHISHI_KEYUSAGE_INITIATOR_SEAL = 24,
+  SHISHI_KEYUSAGE_INITIATOR_SIGN = 25,
+  /* 16-18,20-21,25-511. Reserved for future use in Kerberos and related
+     protocols. */
+  /* 512-1023.      Reserved for uses internal to a Kerberos
+     implementation. */
+  /* 1024.         Encryption for application use in protocols that
+     do not specify key usage values */
+  /* 1025.         Checksums for application use in protocols that
+     do not specify key usage values */
+  /* 1026-2047.      Reserved for application use.
+     1026,1028,1030,1032,1034 used in KCMD protocol */
+  SHISHI_KEYUSAGE_KCMD_DES = 1026,
+  SHISHI_KEYUSAGE_KCMD_INPUT = 1028,
+  SHISHI_KEYUSAGE_KCMD_OUTPUT = 1030,
+  SHISHI_KEYUSAGE_KCMD_STDERR_INPUT = 1032,
+  SHISHI_KEYUSAGE_KCMD_STDERR_OUTPUT = 1034
 }
 Shishi_keyusage;
 
@@ -557,6 +575,7 @@ typedef struct Shishi_priv Shishi_priv;
 typedef struct node_asn_struct *ASN1_TYPE;
 #endif
 typedef ASN1_TYPE Shishi_asn1;
+typedef struct Shishi_crypto Shishi_crypto;
 
 /* init.c */
 extern Shishi *shishi (void);
@@ -580,6 +599,7 @@ extern const char *shishi_cfg_default_userdirectory (Shishi * handle);
 extern const char *shishi_cfg_default_userfile (Shishi * handle);
 extern int shishi_cfg_clientkdcetype (Shishi * handle, int32_t ** etypes);
 extern int shishi_cfg_clientkdcetype_set (Shishi * handle, char *value);
+extern int shishi_cfg_authorizationtype_set (Shishi * handle, char *value);
 
 /* error.c */
 extern const char *shishi_strerror (int err);
@@ -776,7 +796,7 @@ extern Shishi_tkt *shishi_tkts_get_tgt (Shishi_tkts * tkts,
 					Shishi_tkts_hint * hint);
 extern Shishi_tkt *shishi_tkts_get_tgs (Shishi_tkts * tkts,
 					Shishi_tkts_hint * hint,
-					Shishi_tkt *tgt);
+					Shishi_tkt * tgt);
 extern Shishi_tkt *shishi_tkts_get_for_clientserver (Shishi_tkts * tkts,
 						     const char *client,
 						     const char *server);
@@ -1030,7 +1050,7 @@ extern int shishi_kdcreq_etype (Shishi * handle, Shishi_asn1 kdcreq,
 extern int shishi_kdcreq_set_etype (Shishi * handle, Shishi_asn1 kdcreq,
 				    int32_t * etype, int netype);
 extern int shishi_kdcreq_options (Shishi * handle, Shishi_asn1 kdcreq,
-				  uint32_t *flags);
+				  uint32_t * flags);
 extern int shishi_kdcreq_renewable_p (Shishi * handle, Shishi_asn1 kdcreq);
 extern int shishi_kdcreq_options_set (Shishi * handle, Shishi_asn1 kdcreq,
 				      uint32_t options);
@@ -1418,6 +1438,19 @@ extern int shishi_pbkdf2_sha1 (Shishi * handle,
 			       const char *S, size_t Slen,
 			       unsigned int c, unsigned int dkLen, char *DK);
 
+/* crypto-ctx.c */
+extern Shishi_crypto *shishi_crypto (Shishi * handle,
+				     Shishi_key * key, int keyusage,
+				     int32_t etype,
+				     const char *iv, size_t ivlen);
+extern void shishi_crypto_close (Shishi_crypto * ctx);
+extern int shishi_crypto_encrypt (Shishi_crypto * ctx,
+				  const char *in, size_t inlen,
+				  char **out, size_t * outlen);
+extern int shishi_crypto_decrypt (Shishi_crypto * ctx,
+				  const char *in, size_t inlen,
+				  char **out, size_t * outlen);
+
 /* version.c */
 extern const char *shishi_check_version (const char *req_version);
 
@@ -1448,7 +1481,7 @@ extern int shishi_asn1_read_int32 (Shishi * handle, Shishi_asn1 node,
 extern int shishi_asn1_read_uint32 (Shishi * handle, Shishi_asn1 node,
 				    const char *field, uint32_t * i);
 extern int shishi_asn1_read_bitstring (Shishi * handle, Shishi_asn1 node,
-				       const char *field, uint32_t *flags);
+				       const char *field, uint32_t * flags);
 extern int shishi_asn1_read_optional (Shishi * handle,
 				      Shishi_asn1 node, const char *field,
 				      char *data, size_t * datalen);
@@ -1939,8 +1972,7 @@ extern int shishi_priv_read (Shishi * handle, FILE * fh, Shishi_asn1 * priv);
 extern int shishi_priv_from_file (Shishi * handle, Shishi_asn1 * priv,
 				  int filetype, const char *filename);
 extern int shishi_priv_enc_part_etype (Shishi * handle,
-				       Shishi_asn1 priv,
-				       int32_t * etype);
+				       Shishi_asn1 priv, int32_t * etype);
 extern int shishi_priv_set_enc_part (Shishi * handle,
 				     Shishi_asn1 priv,
 				     int32_t etype,
@@ -1956,4 +1988,9 @@ extern int shishi_encprivpart_set_user_data (Shishi * handle,
 extern int shishi_priv_build (Shishi_priv * priv, Shishi_key * key);
 extern int shishi_priv_process (Shishi_priv * priv, Shishi_key * key);
 
+/* authorize.c */
+extern int shishi_authorized_p (Shishi * handle,
+				Shishi_tkt * tkt, const char *authzname);
+extern int shishi_authorization_parse (const char *authorization);
+
 #endif
