@@ -34,8 +34,7 @@
  **/
 int
 shishi_ticket_realm_get (Shishi * handle,
-			 Shishi_asn1 ticket,
-			 char **realm, size_t *realmlen)
+			 Shishi_asn1 ticket, char **realm, size_t * realmlen)
 {
   return shishi_asn1_read2 (handle, ticket, "realm", realm, realmlen);
 }
@@ -131,25 +130,20 @@ shishi_ticket_set_server (Shishi * handle,
   int res;
   int i;
 
-  tmpserver = strdup (server);
-  if (tmpserver == NULL)
-    return SHISHI_MALLOC_ERROR;
+  tmpserver = xstrdup (server);
+  serverbuf = xmalloc (sizeof (*serverbuf));
 
-  serverbuf = malloc (sizeof (*serverbuf));
   for (i = 0;
        (serverbuf[i] = strtok_r (i == 0 ? tmpserver : NULL, "/", &tokptr));
        i++)
     {
-      serverbuf = realloc (serverbuf, (i + 2) * sizeof (*serverbuf));
-      if (serverbuf == NULL)
-	return SHISHI_MALLOC_ERROR;
+      serverbuf = xrealloc (serverbuf, (i + 2) * sizeof (*serverbuf));
     }
   res = shishi_ticket_sname_set (handle, ticket,
 				 SHISHI_NT_PRINCIPAL, serverbuf);
   if (res != SHISHI_OK)
     {
-      fprintf (stderr, _("Could not set sname: %s\n"),
-	       shishi_strerror_details (handle));
+      fprintf (stderr, _("Could not set sname: %s\n"), shishi_error (handle));
       return res;
     }
   free (serverbuf);
@@ -161,7 +155,7 @@ shishi_ticket_set_server (Shishi * handle,
 int
 shishi_ticket_snamerealm_get (Shishi * handle,
 			      Shishi_asn1 ticket,
-			      char *serverrealm, int *serverrealmlen)
+			      char *serverrealm, size_t * serverrealmlen)
 {
   return shishi_principal_name_realm_get (handle, ticket, "sname",
 					  ticket, "realm",
